%global ver_type stable

%{?perl_default_filter}

Summary:       Tools to access and modify virtual machine disk images
Name:          guestfs-tools
Version:       1.51.4
%global major_ver %(echo %version | cut -d. -f1)
%global minor_ver %(echo %version | cut -d. -f2)
%if %(echo $((%minor_ver % 2))) == 1
%global ver_type development
%endif
Release:       3%{?dist}
License:       GPLv2+
URL:           http://libguestfs.org/
Source0:       http://download.libguestfs.org/guestfs-tools/%{major_ver}.%{minor_ver}-%{ver_type}/%{name}-%{version}.tar.gz


BuildRequires: gcc gcc-c++ make autoconf automake libtool flex bison
%ifarch x86_64
BuildRequires: glibc-static
%endif
BuildRequires: perl-generators /usr/bin/pod2text po4a bash-completion
BuildRequires: perl(Pod::Simple) perl(Pod::Man) perl(Module::Build) perl(Test::More)
BuildRequires: pcre2-devel libxml2-devel jansson-devel xz-devel gettext-devel
BuildRequires: libosinfo-devel libxcrypt-devel ncurses-devel hwdata-devel
BuildRequires: ocaml-libguestfs-devel ocaml-findlib-devel ocaml-gettext-devel
BuildRequires: libvirt-devel libguestfs-devel libguestfs-xfs
BuildRequires: /usr/bin/qemu-img xorriso
BuildRequires: perl(Locale::TextDomain) perl(Sys::Guestfs)
BuildRequires: perl(Win::Hivex) perl(Win::Hivex::Regedit)

Requires:      curl xz gnupg2
Requires:      libguestfs /usr/bin/qemu-img
Suggests:      osinfo-db perl
Recommends:    hwdata
Provides:      libguestfs-tools-c = %{version}-%{release}


%description
guestfs-tools is a set of tools that can be used to make batch
configuration changes to guests, get disk used/free statistics
(virt-df), perform backups and guest clones, change
registry/UUID/hostname info, build guests from scratch (virt-builder)
and much more.

Virt-alignment-scan scans virtual machines looking for partition
alignment problems.

Virt-builder is a command line tool for rapidly making disk images
of popular free operating systems.

Virt-cat is a command line tool to display the contents of a file in a
virtual machine.

Virt-customize is a command line tool for customizing virtual machine
disk images.

Virt-df is a command line tool to display free space on virtual
machine filesystems.  Unlike other tools, it doesn’t just display the
amount of space allocated to a virtual machine, but can look inside
the virtual machine to see how much space is really being used.  It is
like the df(1) command, but for virtual machines, except that it also
works for Windows virtual machines.

Virt-diff shows the differences between virtual machines.

Virt-drivers detects the bootloader, kernel and drivers inside a guest.

Virt-edit is a command line tool to edit the contents of a file in a
virtual machine.

Virt-filesystems is a command line tool to display the filesystems,
partitions, block devices, LVs, VGs and PVs found in a disk image
or virtual machine.  It replaces the deprecated programs
virt-list-filesystems and virt-list-partitions with a much more
capable tool.

Virt-format is a command line tool to erase and make blank disks.

Virt-get-kernel extracts a kernel/initrd from a disk image.

Virt-inspector examines a virtual machine and tries to determine the
version of the OS, the kernel version, what drivers are installed,
whether the virtual machine is fully virtualized (FV) or
para-virtualized (PV), what applications are installed and more.

Virt-log is a command line tool to display the log files from a
virtual machine.

Virt-ls is a command line tool to list out files in a virtual machine.

Virt-make-fs is a command line tool to build a filesystem out of
a collection of files or a tarball.

Virt-resize can resize existing virtual machine disk images.

Virt-sparsify makes virtual machine disk images sparse (thin-provisioned).

Virt-sysprep lets you reset or unconfigure virtual machines in
preparation for cloning them.

Virt-tail follows (tails) a log file within a guest, like 'tail -f'.


%package -n virt-win-reg
Summary:       Access and modify the Windows Registry of a Windows VM
License:       GPLv2+
BuildArch:     noarch
Provides:      libguestfs-tools = %{version}-%{release}

%description -n virt-win-reg
Virt-win-reg lets you look at and modify the Windows Registry of
Windows virtual machines.


%package bash-completion
Summary:       Bash tab-completion scripts for %{name}
BuildArch:     noarch
Requires:      bash-completion >= 2.0
Requires:      %{name} = %{version}-%{release}

%description bash-completion
Install this package if you want intelligent bash tab-completion
for the virt-* tools.


%prep
%autosetup -p1


%build
autoreconf -i
%{configure}
make -j1 -C builder index-parse.c
%make_build


%check
%ifarch x86_64
if grep CONFIG_DEBUG_MUTEXES=y /lib/modules/*/config ; then
    echo "Skipping tests because debug kernel is installed"
    exit 0
fi

export LIBGUESTFS_DEBUG=1
export LIBGUESTFS_TRACE=1

export SKIP_TEST_MACHINE_READABLE_SH=1
# Test fails in mock
export SKIP_TEST_VIRT_FORMAT_SH=1
# Test too long and times out.
export SKIP_TEST_VIRT_RESIZE_PL=1

make check -k || cat test-suite.log

%endif


%install
%make_install
find $RPM_BUILD_ROOT -name '*.la' -delete

mv $RPM_BUILD_ROOT%{_docdir}/%{name} installed-docs
gzip --best installed-docs/*.xml

%find_lang %{name}


%pretrans -p <lua>
path = "/etc/virt-builder"
st = posix.stat(path)
if st and st.type == "link" then
  os.remove(path)
end


%files -f %{name}.lang
%license COPYING
%doc README installed-docs/*
%dir %{_sysconfdir}/virt-builder
%dir %{_sysconfdir}/virt-builder/repos.d
%config(noreplace) %{_sysconfdir}/virt-builder/repos.d/*
%{_bindir}/virt-alignment-scan
%{_bindir}/virt-builder
%{_bindir}/virt-builder-repository
%{_bindir}/virt-cat
%{_bindir}/virt-customize
%{_bindir}/virt-df
%{_bindir}/virt-diff
%{_bindir}/virt-drivers
%{_bindir}/virt-edit
%{_bindir}/virt-filesystems
%{_bindir}/virt-format
%{_bindir}/virt-get-kernel
%{_bindir}/virt-index-validate
%{_bindir}/virt-inspector
%{_bindir}/virt-log
%{_bindir}/virt-ls
%{_bindir}/virt-make-fs
%{_bindir}/virt-resize
%{_bindir}/virt-sparsify
%{_bindir}/virt-sysprep
%{_bindir}/virt-tail
%{_mandir}/man1/guestfs-tools-release-notes-1*.1*
%{_mandir}/man1/virt-alignment-scan.1*
%{_mandir}/man1/virt-builder-repository.1*
%{_mandir}/man1/virt-builder.1*
%{_mandir}/man1/virt-cat.1*
%{_mandir}/man1/virt-customize.1*
%{_mandir}/man1/virt-df.1*
%{_mandir}/man1/virt-diff.1*
%{_mandir}/man1/virt-drivers.1*
%{_mandir}/man1/virt-edit.1*
%{_mandir}/man1/virt-filesystems.1*
%{_mandir}/man1/virt-format.1*
%{_mandir}/man1/virt-get-kernel.1*
%{_mandir}/man1/virt-index-validate.1*
%{_mandir}/man1/virt-inspector.1*
%{_mandir}/man1/virt-log.1*
%{_mandir}/man1/virt-ls.1*
%{_mandir}/man1/virt-make-fs.1*
%{_mandir}/man1/virt-resize.1*
%{_mandir}/man1/virt-sparsify.1*
%{_mandir}/man1/virt-sysprep.1*
%{_mandir}/man1/virt-tail.1*
%exclude %{_mandir}/ja/man1/*.1*
%exclude %{_mandir}/uk/man1/*.1*


%files -n virt-win-reg
%license COPYING
%doc README
%{_bindir}/virt-win-reg
%{_mandir}/man1/virt-win-reg.1*


%files bash-completion
%license COPYING
%dir %{_datadir}/bash-completion/completions
%{_datadir}/bash-completion/completions/virt-*


%changelog
* Tue Mar 19 2024 Rebuild Robot <rebot@opencloudos.org> - 1.51.4-3
- Rebuilt for jansson

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.51.4-2
- Rebuilt for OpenCloudOS Stream 23.09

* Fri Aug 11 2023 rockerzhu <rockerzhu@tencent.com> - 1.51.4-1
- Upgrade to 1.51.4 to build with ocaml 5.0.

* Fri Jul 21 2023 Xiaojie Chen <jackxjchen@tencent.com> - 1.51.2-2
- Remove the use of bc

* Thu Jul 13 2023 Xiaojie Chen <jackxjchen@tencent.com> - 1.51.2-1
- Upgrade to upstream version 1.51.2

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.50.0-2
- Rebuilt for OpenCloudOS Stream 23.05

* Thu Apr 06 2023 rockerzhu <rockerzhu@tencent.com> - 1.50.0-1
- Initial build.
